sky_design_system library

Core UI components, tokens, themes, and extensions for the design system.

Classes

AppAvatar
An avatar widget displaying initials or a background image.
AppBadge
A badge widget that displays an optional count or status dot.
AppBorderRadius
Design system token values for BorderRadius.
AppBottomSheet
A sheet that slides up from the bottom of the screen.
AppBottomSheetPage<T>
A Page that displays an AppBottomSheet as a declarative route.
AppButton
A button widget supporting multiple styles and an optional icon.
AppCard
A card container widget with support for headers and gestures.
AppCheckbox
A standard checkbox input widget.
AppColors
Pre-defined color schemes for the design system.
AppColorScheme
Represents the design system's Material 3 color tokens.
AppDatePickerField
A field that opens a date picker dialog when tapped.
AppDialog
A modal message dialog widget.
AppDialogPage<T>
A Page that displays an AppDialog as a declarative route.
AppDivider
A visual separator line widget.
AppIcon
A widget for displaying system icons with standard sizes.
AppIconButton
A button widget consisting of a single icon.
AppImage
A highly optimized, universal image rendering widget for the Sky Design System.
AppListTile
A single fixed-height row that contains text and optional icons.
AppNavigationBar
A bottom navigation bar widget.
AppNavigationDrawer
A sidebar drawer navigation widget.
AppNavigationRail
A sidebar rail navigation widget.
AppProgressIndicator
A linear or circular progress indicator.
AppRadioButton<T>
A single radio button selector widget.
AppRadioGroup<T>
A group of mutually exclusive radio buttons.
AppRadius
Design system token values for corner radius (in dp).
AppRichText
A rich text component that displays styled text in sections.
AppScaffold
A general page layout container.
AppScrollView
A parent scrollable layout container designed for forms and screens.
AppSearchBar
A search input field.
AppShimmer
A reusable skeleton loader (Shimmer) atom widget.
AppSlider
A slider input widget to select from a range of values.
AppSliverScrollView
A parent scrollable layout container designed for screens requiring slivers (e.g. sliver app bars).
AppSnackBar
A utility class for building and presenting snackbar notifications.
AppSpacing
Design system token values for spacing and layout grids (in dp).
AppSpan
Base class for all spans used in AppRichText.
AppSwitch
A standard toggle switch input widget.
AppTabBar
A tab bar container widget.
AppText
A stylized typography component.
AppTextField
A text input field widget.
AppTextSpan
A text span component for AppRichText that integrates with the design system's typography.
AppTheme
Configures theme parameters using design tokens.
AppTimePickerField
A field that opens a time picker dialog when tapped.
AppTooltip
A tooltip wrapper widget.
AppTopBar
A header bar for screens.
AppTypography
Typography definitions and TextTheme tokens.
AppWidgetSpan
A widget span component for AppRichText to insert arbitrary widgets (like icons or images) inline.

Extensions

SkyDesignSystemContextExtension on BuildContext
Theme and design system context extensions on BuildContext.